==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/ImageChangeCauseFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ImageChangeCauseFluentImpl<A extends io.fabric8.openshift.api.model.ImageChangeCauseFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ImageChangeCauseFluent<A>{
  public ImageChangeCauseFluentImpl() {
  }
  public ImageChangeCauseFluentImpl(io.fabric8.openshift.api.model.ImageChangeCause instance) {
    this.withFromRef(instance.getFromRef()); 
    this.withImageID(instance.getImageID()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.ObjectReferenceBuilder fromRef;
  private java.lang.String imageID;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildFromRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectReference getFromRef() {
    return this.fromRef!=null?this.fromRef.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectReference buildFromRef() {
    return this.fromRef!=null?this.fromRef.build():null;
  }
  public A withFromRef(io.fabric8.kubernetes.api.model.ObjectReference fromRef) {
    _visitables.get("fromRef").remove(this.fromRef);
    if (fromRef!=null){ this.fromRef= new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(fromRef); _visitables.get("fromRef").add(this.fromRef);} return (A) this;
  }
  public java.lang.Boolean hasFromRef() {
    return this.fromRef != null;
  }
  public io.fabric8.openshift.api.model.ImageChangeCauseFluent.FromRefNested<A> withNewFromRef() {
    return new io.fabric8.openshift.api.model.ImageChangeCauseFluentImpl.FromRefNestedImpl();
  }
  public io.fabric8.openshift.api.model.ImageChangeCauseFluent.FromRefNested<A> withNewFromRefLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return new io.fabric8.openshift.api.model.ImageChangeCauseFluentImpl.FromRefNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ImageChangeCauseFluent.FromRefNested<A> editFromRef() {
    return withNewFromRefLike(getFromRef());
  }
  public io.fabric8.openshift.api.model.ImageChangeCauseFluent.FromRefNested<A> editOrNewFromRef() {
    return withNewFromRefLike(getFromRef() != null ? getFromRef(): new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.ImageChangeCauseFluent.FromRefNested<A> editOrNewFromRefLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return withNewFromRefLike(getFromRef() != null ? getFromRef(): item);
  }
  public java.lang.String getImageID() {
    return this.imageID;
  }
  public A withImageID(java.lang.String imageID) {
    this.imageID=imageID; return (A) this;
  }
  public java.lang.Boolean hasImageID() {
    return this.imageID != null;
  }
  
  /**
   * Method is deprecated. use withImageID instead.
   */
  @java.lang.Deprecated
  public A withNewImageID(java.lang.String arg0) {
    return (A)withImageID(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageChangeCauseFluentImpl that = (ImageChangeCauseFluentImpl) o;
    if (fromRef != null ? !fromRef.equals(that.fromRef) :that.fromRef != null) return false;
    if (imageID != null ? !imageID.equals(that.imageID) :that.imageID != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fromRef,  imageID,  additionalProperties,  super.hashCode());
  }
  public class FromRefNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl<io.fabric8.openshift.api.model.ImageChangeCauseFluent.FromRefNested<N>> implements io.fabric8.openshift.api.model.ImageChangeCauseFluent.FromRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    FromRefNestedImpl(io.fabric8.kubernetes.api.model.ObjectReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this, item);
    }
    FromRefNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectReferenceBuilder builder;
    public N and() {
      return (N) ImageChangeCauseFluentImpl.this.withFromRef(builder.build());
    }
    public N endFromRef() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/ImageChangeCauseFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ImageChangeCauseFluentImpl<A extends io.fabric8.openshift.api.model.ImageChangeCauseFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ImageChangeCauseFluent<A>{
  public ImageChangeCauseFluentImpl() {
  }
  public ImageChangeCauseFluentImpl(io.fabric8.openshift.api.model.ImageChangeCause instance) {
    this.withFromRef(instance.getFromRef()); 
    this.withImageID(instance.getImageID()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.ObjectReferenceBuilder fromRef;
  private java.lang.String imageID;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildFromRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectReference getFromRef() {
    return this.fromRef!=null?this.fromRef.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectReference buildFromRef() {
    return this.fromRef!=null?this.fromRef.build():null;
  }
  public A withFromRef(io.fabric8.kubernetes.api.model.ObjectReference fromRef) {
    _visitables.get("fromRef").remove(this.fromRef);
    if (fromRef!=null){ this.fromRef= new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(fromRef); _visitables.get("fromRef").add(this.fromRef);} return (A) this;
  }
  public java.lang.Boolean hasFromRef() {
    return this.fromRef != null;
  }
  public io.fabric8.openshift.api.model.ImageChangeCauseFluent.FromRefNested<A> withNewFromRef() {
    return new io.fabric8.openshift.api.model.ImageChangeCauseFluentImpl.FromRefNestedImpl();
  }
  public io.fabric8.openshift.api.model.ImageChangeCauseFluent.FromRefNested<A> withNewFromRefLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return new io.fabric8.openshift.api.model.ImageChangeCauseFluentImpl.FromRefNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.ImageChangeCauseFluent.FromRefNested<A> editFromRef() {
    return withNewFromRefLike(getFromRef());
  }
  public io.fabric8.openshift.api.model.ImageChangeCauseFluent.FromRefNested<A> editOrNewFromRef() {
    return withNewFromRefLike(getFromRef() != null ? getFromRef(): new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.ImageChangeCauseFluent.FromRefNested<A> editOrNewFromRefLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return withNewFromRefLike(getFromRef() != null ? getFromRef(): item);
  }
  public java.lang.String getImageID() {
    return this.imageID;
  }
  public A withImageID(java.lang.String imageID) {
    this.imageID=imageID; return (A) this;
  }
  public java.lang.Boolean hasImageID() {
    return this.imageID != null;
  }
  
  /**
   * Method is deprecated. use withImageID instead.
   */
  @java.lang.Deprecated
  public A withNewImageID(java.lang.String arg0) {
    return (A)withImageID(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageChangeCauseFluentImpl that = (ImageChangeCauseFluentImpl) o;
    if (fromRef != null ? !fromRef.equals(that.fromRef) :that.fromRef != null) return false;
    if (imageID != null ? !imageID.equals(that.imageID) :that.imageID != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fromRef,  imageID,  additionalProperties,  super.hashCode());
  }
  public class FromRefNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl<io.fabric8.openshift.api.model.ImageChangeCauseFluent.FromRefNested<N>> implements io.fabric8.openshift.api.model.ImageChangeCauseFluent.FromRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    FromRefNestedImpl(io.fabric8.kubernetes.api.model.ObjectReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this, item);
    }
    FromRefNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectReferenceBuilder builder;
    public N and() {
      return (N) ImageChangeCauseFluentImpl.this.withFromRef(builder.build());
    }
    public N endFromRef() {
      return and();
    }
    
  }
  
}
